@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2017, The pgAdmin Development Team
+# Copyright (C) 2013 - 2019, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -14,28 +14,32 @@ from functools import wraps
 
 import pgadmin.browser.server_groups.servers.databases as database
 from flask import render_template, make_response, request, jsonify
-from flask_babel import gettext as _
-from pgadmin.browser.server_groups.servers.databases.schemas.tables.constraints.type \
-    import ConstraintRegistry, ConstraintTypeModule
+from flask_babelex import gettext as _
+from pgadmin.browser.server_groups.servers.databases.schemas.tables.\
+    constraints.type import ConstraintRegistry, ConstraintTypeModule
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
-    make_response as ajax_response
+    make_response as ajax_response, gone
 from pgadmin.utils.driver import get_driver
-
 from config import PG_DEFAULT_DRIVER
-from pgadmin.utils.ajax import gone
+from pgadmin.utils import IS_PY2
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class IndexConstraintModule(ConstraintTypeModule):
     """
     class IndexConstraintModule(CollectionNodeModule)
 
-        A module class for Primary key constraint node derived from ConstraintTypeModule.
+        A module class for Primary key constraint node derived from
+        ConstraintTypeModule.
 
     Methods:
     -------
     * __init__(*args, **kwargs)
-      - Method is used to initialize the PrimaryKeyConstraintModule and it's base module.
+      - Method is used to initialize the PrimaryKeyConstraintModule and
+      it's base module.
 
     * get_nodes(gid, sid, did)
       - Method is used to generate the browser collection node.
@@ -53,7 +57,8 @@ class IndexConstraintModule(ConstraintTypeModule):
 
     def __init__(self, *args, **kwargs):
         """
-        Method is used to initialize the PrimaryKeyConstraintModule and it's base module.
+        Method is used to initialize the PrimaryKeyConstraintModule and
+        it's base module.
 
         Args:
           *args:
@@ -91,12 +96,21 @@ class IndexConstraintModule(ConstraintTypeModule):
         """
         return database.DatabaseModule.NODE_TYPE
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 class PrimaryKeyConstraintModule(IndexConstraintModule):
     """
      class PrimaryKeyConstraintModule(IndexConstraintModule)
 
-        A module class for the catalog schema node derived from IndexConstraintModule.
+        A module class for the catalog schema node derived from
+        IndexConstraintModule.
     """
 
     NODE_TYPE = 'primary_key'
@@ -110,7 +124,8 @@ class UniqueConstraintModule(IndexConstraintModule):
     """
      class UniqueConstraintModule(IndexConstraintModule)
 
-        A module class for the catalog schema node derived from IndexConstraintModule.
+        A module class for the catalog schema node derived from
+        IndexConstraintModule.
     """
 
     NODE_TYPE = 'unique_constraint'
@@ -124,14 +139,16 @@ class IndexConstraintView(PGChildNodeView):
     """
     class PrimaryKeyConstraintView(PGChildNodeView)
 
-        A view class for Primary key constraint node derived from PGChildNodeView. This class is
-        responsible for all the stuff related to view like creating, updating Primary key constraint
+        A view class for Primary key constraint node derived from
+        PGChildNodeView. This class is responsible for all the stuff related
+        to view like creating, updating Primary key constraint
         node, showing properties, showing sql in sql pane.
 
     Methods:
     -------
     * __init__(**kwargs)
-      - Method is used to initialize the PrimaryKeyConstraintView and it's base view.
+      - Method is used to initialize the PrimaryKeyConstraintView and
+      it's base view.
 
     * module_js()
       - This property defines (if javascript) exists for this node.
@@ -147,8 +164,8 @@ class IndexConstraintView(PGChildNodeView):
         collection as http response.
 
     * get_list()
-      - This function is used to list all the language nodes within that collection
-        and return list of primary key constraint nodes.
+      - This function is used to list all the language nodes within that
+      collection and return list of primary key constraint nodes.
 
     * nodes()
       - This function returns child node within that collection.
@@ -164,13 +181,15 @@ class IndexConstraintView(PGChildNodeView):
       - This function will update the data for the selected primary key.
 
     * msql()
-      - This function is used to return modified SQL for the selected primary key.
+      - This function is used to return modified SQL for the selected primary
+      key.
 
     * get_sql()
       - This function will generate sql from model data.
 
     * sql():
-      - This function will generate sql to show it in sql pane for the selected primary key.
+      - This function will generate sql to show it in sql pane for the
+      selected primary key.
 
     * get_indices():
         - This function returns indices for current table.
@@ -201,9 +220,9 @@ class IndexConstraintView(PGChildNodeView):
     operations = dict({
         'obj': [
             {'get': 'properties', 'delete': 'delete', 'put': 'update'},
-            {'get': 'list', 'post': 'create'}
+            {'get': 'list', 'post': 'create', 'delete': 'delete'}
         ],
-        'delete': [{'delete': 'delete'}],
+        'delete': [{'delete': 'delete'}, {'delete': 'delete'}],
         'children': [{'get': 'children'}],
         'nodes': [{'get': 'node'}, {'get': 'nodes'}],
         'sql': [{'get': 'sql'}],
@@ -244,7 +263,8 @@ class IndexConstraintView(PGChildNodeView):
                 kwargs['sid']
             )
             self.conn = self.manager.connection(did=kwargs['did'])
-            self.template_path = 'index_constraint/sql'
+            self.template_path = 'index_constraint/sql/#{0}#'\
+                .format(self.manager.version)
 
             # We need parent's name eg table name and schema name
             SQL = render_template("/".join([self.template_path,
@@ -304,7 +324,7 @@ class IndexConstraintView(PGChildNodeView):
         sql = render_template(
             "/".join([self.template_path, 'get_constraint_cols.sql']),
             cid=cid,
-            colcnt=result['indnatts'])
+            colcnt=result['col_count'])
         status, res = self.conn.execute_dict(sql)
 
         if not status:
@@ -316,6 +336,18 @@ class IndexConstraintView(PGChildNodeView):
 
         result['columns'] = columns
 
+        # Add Include details of the index supported for PG-11+
+        if self.manager.version >= 110000:
+            sql = render_template(
+                "/".join([self.template_path, 'get_constraint_include.sql']),
+                cid=cid)
+            status, res = self.conn.execute_dict(sql)
+
+            if not status:
+                return internal_server_error(errormsg=res)
+
+            result['include'] = [col['colname'] for col in res['rows']]
+
         return ajax_response(
             response=result,
             status=200
@@ -363,11 +395,10 @@ class IndexConstraintView(PGChildNodeView):
         Returns:
 
         """
-        self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(
-                sid
-            )
+        self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(sid)
         self.conn = self.manager.connection(did=did)
-        self.template_path = 'index_constraint/sql'
+        self.template_path = 'index_constraint/sql/#{0}#'\
+            .format(self.manager.version)
 
         # We need parent's name eg table name and schema name
         SQL = render_template("/".join([self.template_path,
@@ -420,15 +451,15 @@ class IndexConstraintView(PGChildNodeView):
             )))
 
         res = self.blueprint.generate_browser_node(
-                rset['rows'][0]['oid'],
-                tid,
-                rset['rows'][0]['name'],
-                icon="icon-%s" % self.node_type
-            )
+            rset['rows'][0]['oid'],
+            tid,
+            rset['rows'][0]['name'],
+            icon="icon-%s" % self.node_type
+        )
         return make_json_response(
-                data=res,
-                status=200
-            )
+            data=res,
+            status=200
+        )
 
     @check_precondition
     def nodes(self, gid, sid, did, scid, tid):
@@ -464,11 +495,12 @@ class IndexConstraintView(PGChildNodeView):
                     tid,
                     row['name'],
                     icon="icon-%s" % self.node_type
-                ))
-        return make_json_response(
-                data=res,
-                status=200
+                )
             )
+        return make_json_response(
+            data=res,
+            status=200
+        )
 
     def get_nodes(self, gid, sid, did, scid, tid, cid=None):
         """
@@ -485,11 +517,10 @@ class IndexConstraintView(PGChildNodeView):
         Returns:
 
         """
-        self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(
-                sid
-            )
+        self.manager = get_driver(PG_DEFAULT_DRIVER).connection_manager(sid)
         self.conn = self.manager.connection(did=did)
-        self.template_path = 'index_constraint/sql'
+        self.template_path = 'index_constraint/sql/#{0}#'\
+            .format(self.manager.version)
 
         # We need parent's name eg table name and schema name
         SQL = render_template("/".join([self.template_path,
@@ -545,24 +576,30 @@ class IndexConstraintView(PGChildNodeView):
 
         for k, v in data.items():
             try:
-                data[k] = json.loads(v, encoding='utf-8')
+                # comments should be taken as is because if user enters a
+                # json comment it is parsed by loads which should not happen
+                if k in ('comment',):
+                    data[k] = v
+                else:
+                    data[k] = json.loads(v, encoding='utf-8')
             except (ValueError, TypeError, KeyError):
                 data[k] = v
 
+        def is_key_list(key, data):
+            return isinstance(data[key], list) and len(data[param]) > 0
+
         for arg in required_args:
             if isinstance(arg, list):
                 for param in arg:
-                    if (param in data and
-                            (not isinstance(data[param], list) or
-                                 (isinstance(data[param], list) and
-                                          len(data[param]) > 0))):
+                    if param in data and is_key_list(param, data):
                         break
                 else:
                     return make_json_response(
                         status=400,
                         success=0,
                         errormsg=_(
-                            "Could not find at least one required parameter (%s)." % str(param)
+                            "Could not find at least one required "
+                            "parameter (%s)." % str(param)
                         )
                     )
 
@@ -616,10 +653,12 @@ class IndexConstraintView(PGChildNodeView):
                 data['name'] = res['rows'][0]['name']
 
             else:
-                sql = render_template("/".join([self.template_path, 'get_oid.sql']),
-                                      tid=tid,
-                                      constraint_type=self.constraint_type,
-                                      name=data['name'])
+                sql = render_template(
+                    "/".join([self.template_path, 'get_oid.sql']),
+                    tid=tid,
+                    constraint_type=self.constraint_type,
+                    name=data['name']
+                )
                 status, res = self.conn.execute_dict(sql)
                 if not status:
                     self.end_transaction()
@@ -667,16 +706,20 @@ class IndexConstraintView(PGChildNodeView):
             data['schema'] = self.schema
             data['table'] = self.table
             sql, name = self.get_sql(data, did, tid, cid)
+            if not isinstance(sql, (str, unicode)):
+                return sql
             sql = sql.strip('\n').strip(' ')
 
             status, res = self.conn.execute_scalar(sql)
             if not status:
                 return internal_server_error(errormsg=res)
 
-            sql = render_template("/".join([self.template_path, 'get_oid.sql']),
-                                  tid=tid,
-                                  constraint_type=self.constraint_type,
-                                  name=data['name'])
+            sql = render_template(
+                "/".join([self.template_path, 'get_oid.sql']),
+                tid=tid,
+                constraint_type=self.constraint_type,
+                name=data['name']
+            )
             status, res = self.conn.execute_dict(sql)
             if not status:
                 return internal_server_error(errormsg=res)
@@ -708,6 +751,13 @@ class IndexConstraintView(PGChildNodeView):
         Returns:
 
         """
+        if cid is None:
+            data = request.form if request.form else json.loads(
+                request.data, encoding='utf-8'
+            )
+        else:
+            data = {'ids': [cid]}
+
         # Below code will decide if it's simple drop or drop with cascade call
         if self.cmd == 'delete':
             # This is a cascade operation
@@ -715,35 +765,39 @@ class IndexConstraintView(PGChildNodeView):
         else:
             cascade = False
         try:
-            sql = render_template("/".join([self.template_path, 'get_name.sql']),
-                                  tid=tid,
-                                  constraint_type=self.constraint_type,
-                                  cid=cid)
-            status, res = self.conn.execute_dict(sql)
-            if not status:
-                return internal_server_error(errormsg=res)
-
-            if not res['rows']:
-                return make_json_response(
-                    success=0,
-                    errormsg=_(
-                        'Error: Object not found.'
-                    ),
-                    info=_(
-                        'The specified constraint could not be found.\n'
-                    )
+            for cid in data['ids']:
+                sql = render_template(
+                    "/".join([self.template_path, 'get_name.sql']),
+                    tid=tid,
+                    constraint_type=self.constraint_type,
+                    cid=cid
                 )
+                status, res = self.conn.execute_dict(sql)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
-            data = res['rows'][0]
-            data['schema'] = self.schema
-            data['table'] = self.table
+                if not res['rows']:
+                    return make_json_response(
+                        success=0,
+                        errormsg=_(
+                            'Error: Object not found.'
+                        ),
+                        info=_(
+                            'The specified constraint could not be found.\n'
+                        )
+                    )
 
-            sql = render_template("/".join([self.template_path, 'delete.sql']),
-                                  data=data,
-                                  cascade=cascade)
-            status, res = self.conn.execute_scalar(sql)
-            if not status:
-                return internal_server_error(errormsg=res)
+                data = res['rows'][0]
+                data['schema'] = self.schema
+                data['table'] = self.table
+
+                sql = render_template("/".join([self.template_path,
+                                                'delete.sql']),
+                                      data=data,
+                                      cascade=cascade)
+                status, res = self.conn.execute_scalar(sql)
+                if not status:
+                    return internal_server_error(errormsg=res)
 
             return make_json_response(
                 success=1,
@@ -779,7 +833,12 @@ class IndexConstraintView(PGChildNodeView):
         data = {}
         for k, v in request.args.items():
             try:
-                data[k] = json.loads(v, encoding='utf-8')
+                # comments should be taken as is because if user enters a
+                # json comment it is parsed by loads which should not happen
+                if k in ('comment',):
+                    data[k] = v
+                else:
+                    data[k] = json.loads(v, encoding='utf-8')
             except ValueError:
                 data[k] = v
 
@@ -787,6 +846,8 @@ class IndexConstraintView(PGChildNodeView):
         data['table'] = self.table
         try:
             sql, name = self.get_sql(data, did, tid, cid)
+            if not isinstance(sql, (str, unicode)):
+                return sql
             sql = sql.strip('\n').strip(' ')
             if sql == '':
                 sql = "--modified SQL"
@@ -811,14 +872,23 @@ class IndexConstraintView(PGChildNodeView):
 
         """
         if cid is not None:
-            sql = render_template("/".join([self.template_path, 'properties.sql']),
-                                  did=did,
-                                  tid=tid,
-                                  cid=cid,
-                                  constraint_type=self.constraint_type)
+            sql = render_template(
+                "/".join([self.template_path, 'properties.sql']),
+                did=did,
+                tid=tid,
+                cid=cid,
+                constraint_type=self.constraint_type
+            )
             status, res = self.conn.execute_dict(sql)
             if not status:
                 return internal_server_error(errormsg=res)
+            if len(res['rows']) == 0:
+                return gone(
+                    _("""Could not find the {} in the table.""".format(
+                        "primary key" if self.constraint_type == "p"
+                        else "unique key"
+                    ))
+                )
 
             old_data = res['rows'][0]
             required_args = [u'name']
@@ -834,15 +904,19 @@ class IndexConstraintView(PGChildNodeView):
                 [u'columns', u'index']  # Either of one should be there.
             ]
 
+            def is_key_str(key, data):
+                return isinstance(data[key], str) and data[key] != ""
+
+            def is_key_list(key, data):
+                return isinstance(data[key], list) and len(data[param]) > 0
+
             for arg in required_args:
                 if isinstance(arg, list):
                     for param in arg:
-                        if (param in data and
-                                ((isinstance(data[param], str) and
-                                          data[param] != "") or
-                                     (isinstance(data[param], list) and
-                                              len(data[param]) > 0))):
-                            break
+                        if param in data:
+                            if is_key_str(param, data) \
+                                    or is_key_list(param, data):
+                                break
                     else:
                         return _('-- definition incomplete')
 
@@ -884,6 +958,10 @@ class IndexConstraintView(PGChildNodeView):
         status, res = self.conn.execute_dict(SQL)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(_("""Could not find the {} in the table.""".format(
+                "primary key" if self.constraint_type == "p" else "unique key"
+            )))
 
         data = res['rows'][0]
         data['schema'] = self.schema
@@ -891,7 +969,7 @@ class IndexConstraintView(PGChildNodeView):
 
         sql = render_template(
             "/".join([self.template_path, 'get_constraint_cols.sql']),
-            cid=cid, colcnt=data['indnatts'])
+            cid=cid, colcnt=data['col_count'])
 
         status, res = self.conn.execute_dict(sql)
 
@@ -904,6 +982,18 @@ class IndexConstraintView(PGChildNodeView):
 
         data['columns'] = columns
 
+        # Add Include details of the index supported for PG-11+
+        if self.manager.version >= 110000:
+            sql = render_template(
+                "/".join([self.template_path, 'get_constraint_include.sql']),
+                cid=cid)
+            status, res = self.conn.execute_dict(sql)
+
+            if not status:
+                return internal_server_error(errormsg=res)
+
+            data['include'] = [col['colname'] for col in res['rows']]
+
         SQL = render_template(
             "/".join([self.template_path, 'create.sql']),
             data=data,
@@ -948,15 +1038,24 @@ class IndexConstraintView(PGChildNodeView):
 
         if is_pgstattuple:
             # Fetch index details only if extended stats available
-            sql = render_template("/".join([self.template_path, 'properties.sql']),
-                                  did=did,
-                                  tid=tid,
-                                  cid=cid,
-                                  constraint_type=self.constraint_type)
+            sql = render_template(
+                "/".join([self.template_path, 'properties.sql']),
+                did=did,
+                tid=tid,
+                cid=cid,
+                constraint_type=self.constraint_type
+            )
             status, res = self.conn.execute_dict(sql)
 
             if not status:
                 return internal_server_error(errormsg=res)
+            if len(res['rows']) == 0:
+                return gone(
+                    _("""Could not find the {} in the table.""".format(
+                        "primary key" if self.constraint_type == "p"
+                        else "unique key"
+                    ))
+                )
 
             result = res['rows'][0]
             name = result['name']
