@@ -960,17 +960,18 @@ define('pgadmin.node.table', [
           id: 'partition_key_note', label: gettext('Partition Keys'),
           type: 'note', group: 'partition', mode: ['create'],
           text: [
-            '<br>&nbsp;&nbsp;',
+            '<ul><li>',
             gettext('Partition table supports two types of keys:'),
-            '<br><ul><li>',
-            gettext('Column: User can select any column from the list of available columns.'),
             '</li><li>',
-            gettext('Expression: User can specify expression to create partition key.'),
-            '<br><p>',
-            gettext('Example'),
-            ':',
+            '<strong>', gettext('Column: '), '</strong>',
+            gettext('User can select any column from the list of available columns.'),
+            '</li><li>',
+            '<strong>', gettext('Expression: '), '</strong>',
+            gettext('User can specify expression to create partition key.'),
+            '</li><li>',
+            '<strong>', gettext('Example: '), '</strong>',
             gettext('Let\'s say, we want to create a partition table based per year for the column \'saledate\', having datatype \'date/timestamp\', then we need to specify the expression as \'extract(YEAR from saledate)\' as partition key.'),
-            '</p></li></ul>',
+            '</li></ul>',
           ].join(''),
           visible: function(m) {
             if(!_.isUndefined(m.node_info) && !_.isUndefined(m.node_info.server)
@@ -990,7 +991,7 @@ define('pgadmin.node.table', [
           canEdit: false, canDelete: true,
           customDeleteTitle: gettext('Detach Partition'),
           customDeleteMsg: gettext('Are you sure you wish to detach this partition?'),
-          columns:['is_attach', 'partition_name', 'values_from', 'values_to', 'values_in', 'values_modulus', 'values_remainder'],
+          columns:['is_attach', 'partition_name', 'is_default', 'values_from', 'values_to', 'values_in', 'values_modulus', 'values_remainder'],
           control: Backform.SubNodeCollectionControl.extend({
             row: Backgrid.PartitionRow,
             initialize: function() {
@@ -1053,22 +1054,28 @@ define('pgadmin.node.table', [
           id: 'partition_note', label: gettext('Partitions'),
           type: 'note', group: 'partition',
           text: [
-            '<ul>',
-            ' <li>',
-            gettext('Create a table: User can create multiple partitions while creating new partitioned table. Operation switch is disabled in this scenario.'),
+            '<ul><li>',
+            '<strong>', gettext('Create a table: '), '</strong>',
+            gettext('User can create multiple partitions while creating new partitioned table. Operation switch is disabled in this scenario.'),
             '</li><li>',
-            gettext('Edit existing table: User can create/attach/detach multiple partitions. In attach operation user can select table from the list of suitable tables to be attached.'),
+            '<strong>', gettext('Edit existing table: '), '</strong>',
+            gettext('User can create/attach/detach multiple partitions. In attach operation user can select table from the list of suitable tables to be attached.'),
             '</li><li>',
+            '<strong>', gettext('Default: '), '</strong>',
+            gettext('The default partition can store rows that do not fall into any existing partition’s range or list.'),
+            '</li><li>',
+            '<strong>', gettext('From/To/In input: '), '</strong>',
             gettext('From/To/In input: Values for these fields must be quoted with single quote. For more than one partition key values must be comma(,) separated.'),
-            '<br>',
-            gettext('Example'),
-            ':<ul><li>',
-            gettext('From/To: Enabled for range partition. Consider partitioned table with multiple keys of type Integer, then values should be specified like \'100\',\'200\'.'),
-            '</li><li> ',
-            gettext('In: Enabled for list partition. Values must be comma(,) separated and quoted with single quote.'),
-            '</li></ul></li></ul>',
-            gettext('Modulus/Remainder: Enabled for hash partition.'),
-            '</li></ul></li></ul>',
+            '</li><li>',
+            '<strong>', gettext('Example: From/To: '), '</strong>',
+            gettext('Enabled for range partition. Consider partitioned table with multiple keys of type Integer, then values should be specified like \'100\',\'200\'.'),
+            '</li><li>',
+            '<strong>', gettext('In: '), '</strong>',
+            gettext('Enabled for list partition. Values must be comma(,) separated and quoted with single quote.'),
+            '</li><li>',
+            '<strong>', gettext('Modulus/Remainder: '), '</strong>',
+            gettext('Enabled for hash partition.'),
+            '</li></ul>',
           ].join(''),
           visible: function(m) {
             if(!_.isUndefined(m.node_info) && !_.isUndefined(m.node_info.server)
