@@ -26,8 +26,19 @@ def close_bgprocess_popup(tester):
     # In cases where restore div is not closed (sometime due to some error)
     try:
         if tester.driver.find_element_by_xpath(
-                "//div[@class='card-header bg-primary d-flex']/div[contains("
-                "text(), 'Restoring backup')]"):
+                "//div[@class='card-header bg-primary d-flex']/div"
+                "[contains(text(), 'Restoring backup')]"):
+            tester.driver.find_element_by_css_selector(
+                ".btn.btn-sm-sq.btn-primary.pg-bg-close > i").click()
+    except Exception:
+        pass
+
+    # In cases where maintenance window is not closed (sometime due to some
+    # error)
+    try:
+        if tester.driver.find_element_by_xpath(
+                "//div[@class='card-header bg-primary d-flex']/div"
+                "[contains(text(), 'Maintenance')]"):
             tester.driver.find_element_by_css_selector(
                 ".btn.btn-sm-sq.btn-primary.pg-bg-close > i").click()
     except Exception:
